==> edge-login-ui-rn-3.4.1.tgz: package/lib/components/ui4/AlertUi4.js <==
/**
 * IMPORTANT: Changes in this file MUST be synced with edge-react-gui!
 */
import * as React from 'react';
import { Platform, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import IonIcon from 'react-native-vector-icons/Ionicons';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
import { CardUi4 } from './CardUi4';
/**
 * A warning or error card that accepts a title, header, bullet points OR normal
 * message, and a footer. The body is considered bullet pointed if an array of
 * strings is given.
 * Bullet points, if provided, are rendered with the correct vertical alignment when
 * the messages overflow.
 *  .___________________________.
 *  | ⚠ Title Text              |
 *  |                           |
 *  | This is the header text   |
 *  |                           |
 *  | • This is an overflowing  |
 *  |   bulletpoint message     |
 *  | • This one's short        |
 *  |                           |
 *  | This is the footer text   |
 *  |___________________________|
 */
export function AlertCardUi4(props) {
    const { title, type, header, body, footer, marginRem, onPress } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const bulletPoint = (bulletPoint) => {
        return (React.createElement(View, { style: styles.bulletpointRow, key: bulletPoint },
            React.createElement(EdgeText, { style: styles.bulletpointText }, '\u2022 '),
            React.createElement(EdgeText, { style: styles.bulletpointText, numberOfLines: 0 }, bulletPoint)));
    };
    return (React.createElement(CardUi4, { gradientBackground: type === 'error' ? theme.cardGradientError : theme.cardGradientWarning, marginRem: marginRem, onPress: onPress },
        React.createElement(View, { style: styles.container },
            React.createElement(View, { style: styles.titleContainer },
                React.createElement(IonIcon, { name: Platform.OS === 'ios'
                        ? 'ios-warning-outline'
                        : 'md-warning-outline', style: styles.icon, color: theme.primaryText, size: theme.rem(1.25) }),
                React.createElement(EdgeText, { numberOfLines: 0, style: styles.titleText }, title)),
            header == null ? null : (React.createElement(EdgeText, { style: styles.text }, header)),
            body == null ? null : typeof body === 'object' && body.length > 0 ? (React.createElement(View, { style: styles.bulletPointContainer }, body.map(point => bulletPoint(point)))) : (React.createElement(EdgeText, { style: styles.text, numberOfLines: 10 }, body)),
            footer == null ? null : (React.createElement(EdgeText, { style: styles.text, numberOfLines: 10 }, footer)))));
}
const getStyles = (theme) => cacheStyles((theme) => ({
    container: {
        margin: theme.rem(0.5)
    },
    titleContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center'
    },
    titleText: {
        marginLeft: theme.rem(0.2),
        fontFamily: theme.fontFaceMedium
    },
    icon: {
        marginRight: theme.rem(0.2)
    },
    text: {
        fontSize: theme.rem(0.75),
        marginHorizontal: theme.rem(0.25),
        marginTop: theme.rem(0.5)
    },
    bulletPointContainer: {
        marginTop: theme.rem(0.5)
    },
    bulletpointRow: {
        flexDirection: 'row'
    },
    bulletpointText: {
        marginLeft: theme.rem(0.2),
        fontSize: theme.rem(0.75)
    }
}))(theme);

==> edge-login-ui-rn-3.17.0.tgz: package/lib/components/ui4/AlertUi4.js <==
/**
 * IMPORTANT: Changes in this file MUST be synced with edge-react-gui!
 */
import * as React from 'react';
import { View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import IonIcon from 'react-native-vector-icons/Ionicons';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
import { CardUi4 } from './CardUi4';
/**
 * A warning or error card that accepts a title, header, bullet points OR normal
 * message, and a footer. The body is considered bullet pointed if an array of
 * strings is given.
 * Bullet points, if provided, are rendered with the correct vertical alignment when
 * the messages overflow.
 *  .___________________________.
 *  | ⚠ Title Text              |
 *  |                           |
 *  | This is the header text   |
 *  |                           |
 *  | • This is an overflowing  |
 *  |   bulletpoint message     |
 *  | • This one's short        |
 *  |                           |
 *  | This is the footer text   |
 *  |___________________________|
 */
export function AlertCardUi4(props) {
    const { title, type, header, body, footer, marginRem, onPress } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const bulletPoint = (bulletPoint) => {
        return (React.createElement(View, { style: styles.bulletpointRow, key: bulletPoint },
            React.createElement(EdgeText, { style: styles.bulletpointText }, '\u2022 '),
            React.createElement(EdgeText, { style: styles.bulletpointText, numberOfLines: 0 }, bulletPoint)));
    };
    return (React.createElement(CardUi4, { gradientBackground: type === 'error' ? theme.cardGradientError : theme.cardGradientWarning, marginRem: marginRem, onPress: onPress },
        React.createElement(View, { style: styles.container },
            React.createElement(View, { style: styles.titleContainer },
                React.createElement(IonIcon, { name: "warning-outline", style: styles.icon, color: theme.primaryText, size: theme.rem(1.25) }),
                React.createElement(EdgeText, { numberOfLines: 0, style: styles.titleText }, title)),
            header == null ? null : (React.createElement(EdgeText, { style: styles.text }, header)),
            body == null ? null : typeof body === 'object' && body.length > 0 ? (React.createElement(View, { style: styles.bulletPointContainer }, body.map(point => bulletPoint(point)))) : (React.createElement(EdgeText, { style: styles.text, numberOfLines: 10 }, body)),
            footer == null ? null : (React.createElement(EdgeText, { style: styles.text, numberOfLines: 10 }, footer)))));
}
const getStyles = (theme) => cacheStyles((theme) => ({
    container: {
        margin: theme.rem(0.5)
    },
    titleContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center'
    },
    titleText: {
        marginLeft: theme.rem(0.2),
        fontFamily: theme.fontFaceMedium
    },
    icon: {
        marginRight: theme.rem(0.2)
    },
    text: {
        fontSize: theme.rem(0.75),
        marginHorizontal: theme.rem(0.25),
        marginTop: theme.rem(0.5)
    },
    bulletPointContainer: {
        marginTop: theme.rem(0.5)
    },
    bulletpointRow: {
        flexDirection: 'row'
    },
    bulletpointText: {
        marginLeft: theme.rem(0.2),
        fontSize: theme.rem(0.75)
    }
}))(theme);
